@@ -20,49 +20,47 @@ export ENIGLANG
 ENIGVERSION=$2
 export ENIGVERSION
 
-LANGDIR=${ENIGLANG}/locale/${ENIGLANG}/enigmail
+LANGDIR=${ENIGLANG}/chrome/locale/${ENIGLANG}/enigmail
 HELPDIR=${LANGDIR}/help
 cwd=`pwd`
 rm -rf ${LANGDIR} >/dev/null 2>&1
 mkdir -p ${LANGDIR} 
 mkdir -p ${HELPDIR}
 
+LANGHASH=`echo "${ENIGLANG}" | md5sum | awk '{ print substr($0,0,2)}'`
+export LANGHASH
+
 # create install.js
 cat > ${ENIGLANG}/install.js <<EOT
 // Install script for Enigmail ${ENIGLANG} language pack
 
-var chromeNode = "${ENIGLANG}";
-
-var vers = "${ENIGVERSION}.0";
-var srDest = 10;       // Disk space required for installation (KB)
-
-var prettyName = chromeNode + " language pack for Enigmail";
-var regName    = "/enigmail-" + chromeNode;
-var chromeName = "enigmail-"+chromeNode + ".jar";
-var localeName = "locale/" + chromeNode + "/";
-
 var err;
+const APP_VERSION="${ENIGVERSION}";
 
-var platformNode = getPlatform();
-logComment("initInstall: platformNode=" + platformNode);
+err = initInstall("Enigmail ${ENIGLANG} Language pack",  // name for install UI
+                  "/enigmail-${ENIGLANG}",   // registered name
+                  APP_VERSION+".0");         // package version
 
-err = initInstall(prettyName, regName, vers);
 logComment("initInstall: " + err);
 
-var fChrome = getFolder("Program", "chrome");
-logComment("fChrome: " + fChrome);
+var srDest = 15;       // Disk space required for installation (KB)
 
-if (!verifyDiskSpace(fChrome, srDest)) {
+var fProgram    = getFolder("Program");
+logComment("fProgram: " + fProgram);
+
+if (!verifyDiskSpace(fProgram, srDest)) {
   cancelInstall(INSUFFICIENT_DISK_SPACE);
 
 } else {
 
-  // addFile: blank, archive_file, install_dir, install_subdir
-  err = addFile("",  chromeName,   fChrome,     "");
+  var fChrome     = getFolder("Chrome");
 
+  // addDirectory: blank, archive_dir, install_dir, install_subdir
+  addDirectory("", "chrome",        fChrome,     "");
+
+  err = getLastError();
   if (err == ACCESS_DENIED) {
-    // Profile chrome does not really work right now; see bug 109044
-    alert("Unable to write to chrome directory "+fChrome+".\n You will need to restart the browser with administrator/root privileges to install this software. After installing as root (or administrator), you will need to restart the browser one more time to register the installed software.\n After the second restart, you can go back to running the browser without privileges!");
+    alert("Unable to write to components directory "+fChrome+".\n You will need to restart the browser with administrator/root privileges to install this software. After installing as root (or administrator), you will need to restart the browser one more time, as a privileged user, to register the installed software.\n After the second restart, you can go back to running the browser without privileges!");
 
     cancelInstall(ACCESS_DENIED);
 
@@ -71,10 +69,8 @@ if (!verifyDiskSpace(fChrome, srDest)) {
 
   } else {
     // Register chrome
-    var chromeJar = getFolder(fChrome, chromeName);
 
-    registerChrome( LOCALE | DELAYED_CHROME, chromeJar,
-                    localeName+"enigmail/");
+    registerChrome( LOCALE | DELAYED_CHROME, getFolder("Chrome","enigmail-${ENIGLANG}.jar"), "locale/${ENIGLANG}/enigmail/");
 
     err = getLastError();
 
@@ -83,22 +79,10 @@ if (!verifyDiskSpace(fChrome, srDest)) {
 
     } else {
       performInstall();
-      logComment("performInstall() returned: " + err);
-
-      if (err == SUCCESS) {
-        alert("Installation finished. RESTART the browser to use this enigmail locale via Edit > Preferences > Appearance > Languages/Content.");
-
-      } else if (err == 999) {
-        alert("Installation finished. REBOOT your system to use this enigmail locale via Edit > Preferences > Appearance > Languages/Content.");
-
-       resetError();
-      }
-
     }
   }
 }
 
-
 // this function verifies disk space in kilobytes
 function verifyDiskSpace(dirPath, spaceRequired) {
   var spaceAvailable;
@@ -119,40 +103,6 @@ function verifyDiskSpace(dirPath, spaceRequired) {
 
   return true;
 }
-
-// OS type detection
-// which platform?
-function getPlatform() {
-  var platformStr;
-  var platformNode;
-
-  if('platform' in Install) {
-    platformStr = new String(Install.platform);
-
-    if (!platformStr.search(/^Macintosh/))
-      platformNode = 'mac';
-    else if (!platformStr.search(/^Win/))
-      platformNode = 'win';
-    else
-      platformNode = 'unix';
-  }
-  else {
-    var fOSMac  = getFolder("Mac System");
-    var fOSWin  = getFolder("Win System");
-
-    logComment("fOSMac: "  + fOSMac);
-    logComment("fOSWin: "  + fOSWin);
-
-    if(fOSMac != null)
-      platformNode = 'mac';
-    else if(fOSWin != null)
-      platformNode = 'win';
-    else
-      platformNode = 'unix';
-  }
-
-  return platformNode;
-}
 EOT
 
 # create install.rdf for Thunderbird 0.7 and newer
@@ -163,24 +113,26 @@ cat > ${ENIGLANG}/install.rdf <<EOT
      xmlns:em="http://www.mozilla.org/2004/em-rdf#">
 
   <Description about="urn:mozilla:install-manifest">
-    <em:id>{847b3a00-7ab0-11d4-8f02-006008948af5}</em:id>
+    <em:id>{847b3a00-7b${LANGHASH}-11d4-8f02-006008948af5}</em:id>
     <em:version>${ENIGVERSION}</em:version>
     
     <!-- Target Application (Thunderbird) this extension can install into, 
-         with minimum and maximum supported versions. --> 
+        with minimum and maximum supported versions. --> 
     <em:targetApplication>
       <Description>
         <em:id>{3550f703-e582-4d05-9a08-453d09bdfdc6}</em:id>
-        <em:minVersion>0.6</em:minVersion>
-        <em:maxVersion>1.0</em:maxVersion>
+        <em:minVersion>0.7</em:minVersion>
+        <em:maxVersion>1.2</em:maxVersion>
       </Description>
     </em:targetApplication>
     
-    
     <!-- Front End MetaData -->
-    <em:name>Enigmail</em:name>
-    <em:description>${ENIGLANG} language pack for Enigmail</em:description>
+    <em:name>Enigmail ${ENIGLANG}</em:name>
+    <em:description>Enigmail ${ENIGLANG} language package</em:description>
+    
+    <!-- Author of the package, replace with your name if you like -->
     <em:creator>Enigmail Team</em:creator>
+    
     <em:homepageURL>http://enigmail.mozdev.org/langpack.html</em:homepageURL>
 
     <!-- Front End Integration Hooks (used by Extension Manager)-->
@@ -196,7 +148,6 @@ cat > ${ENIGLANG}/install.rdf <<EOT
     </em:file>
   </Description>      
 </RDF>
-
 EOT
 
 # create enigmail-xx-YY.spec
@@ -303,9 +254,10 @@ for f in compose.html messenger.html rulesEditor.html editRcptRule.html ; do
   cp ${f} ${cwd}/${HELPDIR} 
 done
 
-cd ${cwd}/${ENIGLANG}
+cd ${cwd}/${ENIGLANG}/chrome
 zip -r -D enigmail-${ENIGLANG}.jar locale
-zip ../enigmail-${ENIGLANG}-${ENIGVERSION}.xpi install.js install.rdf enigmail-${ENIGLANG}.spec enigmail-${ENIGLANG}.jar
+cd ..
+zip ../enigmail-${ENIGLANG}-${ENIGVERSION}.xpi install.js install.rdf enigmail-${ENIGLANG}.spec chrome/enigmail-${ENIGLANG}.jar
 cd ..
 
 test $DEBUG -eq 0 && rm -rf ${ENIGLANG}
