@@ -23,6 +23,8 @@ pref("extensions.enigmail.autoCrypto",false);
 // enable automatically decrypt/verify
 pref("extensions.enigmail.autoDecrypt",true);
 
+// enable X-Enigmail-xxx headers
+pref("extensions.enigmail.addHeaders",true);
 
 // countdown for alerts when composing inline PGP HTML msgs
 pref("extensions.enigmail.composeHtmlAlertCount",3);
@@ -114,6 +116,9 @@ pref("extensions.enigmail.supportMultiPass",false);
 // use GnuPG's default comment for signed messages
 pref("extensions.enigmail.useDefaultComment",false);
 
+// max message size to verify RFC 3156 section 6.1 messages
+pref("extensions.enigmail.encapsulatedMimeMaxSize", 20000);
+
 // use gpg passphrase agent for passphrase handling
 pref("extensions.enigmail.useGpgAgent",false);
 
@@ -144,4 +149,9 @@ pref("mail.identity.default.pgpSignPlain", false);
 pref("mail.identity.default.pgpSignEncrypted", false);
 pref("mail.identity.default.defaultEncryptionPolicy", 0);
 
+/*
+   Other settings (change Mozilla behaviour)
+*/
 
+// disable flowed text by default
+pref("mailnews.send_plaintext_flowed", false);
