@@ -70,7 +70,7 @@ static const PRUint32 kCharMax = 1024;
 
 // nsISupports implementation
 NS_IMPL_THREADSAFE_ISUPPORTS1(nsEnigMimeDecrypt,
-                              nsIEnigMimeDecrypt);
+                              nsIEnigMimeDecrypt)
 
 // nsEnigMimeDecrypt implementation
 nsEnigMimeDecrypt::nsEnigMimeDecrypt()
@@ -304,7 +304,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
       nsCOMPtr<nsIEnigMimeHeaderSink> enigHeaderSink = do_QueryInterface(securityInfo);
       if (enigHeaderSink) {
         NS_NAMED_LITERAL_STRING(nullString, "");
-        rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, -1, 0, nullString.get(), nullString.get(), errorMsg);
+        rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, -1, 0, nullString.get(), nullString.get(), nullString.get(), errorMsg);
       }
     }
 
@@ -330,15 +330,49 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
   rv = mPipeTrans->WriteAsync(bufStream, available, PR_TRUE);
   if (NS_FAILED(rv)) return rv;
 
-  PRUint32 readCount;
+  PRUint32 readCount, iterations;
+  int ctFound = -1;
   char buf[kCharMax];
+  iterations = 0;
+  int status;
   while (1) {
+    ++iterations;
     // Read synchronously
 
     rv = plainStream->Read((char *) buf, kCharMax, &readCount);
     if (NS_FAILED(rv)) return rv;
 
     if (!readCount) break;
+    
+    if (iterations==1 && readCount > 25) {
+      // add mime boundaries around text/plain message (bug 6627)
+      if (nsCRT::strncasecmp("content-type:", buf, 13)==0) {
+        PRUint32 whitespace=13;
+        while((whitespace<readCount) && buf[whitespace] && 
+              ((buf[whitespace]==' ') || (buf[whitespace]=='\t'))) { whitespace++; }
+        if (buf[whitespace] && (whitespace<readCount)) {
+          ctFound=nsCRT::strncasecmp(buf + whitespace, "text/plain", 10);
+          if (ctFound != 0) {
+            ctFound=nsCRT::strncasecmp(buf + whitespace, "text/html", 9);
+          }
+        }
+        if (ctFound==0) {
+          char* header = PR_smprintf(
+          "Content-Type: multipart/mixed; boundary=\"enigDummy\""
+          "\n\n--enigDummy\n");
+          PR_SetError(0,0);
+          status = mOutputFun(header, strlen(header), mOutputClosure);
+          if (status < 0) {
+            PR_SetError(status, 0);
+            mOutputFun = NULL;
+            mOutputClosure = NULL;
+      
+            return NS_ERROR_FAILURE;
+          }
+          mOutputLen += strlen(header);
+        }
+      }
+    }
 
     if (readCount < kCharMax) {
       // make sure we can continue to write later
@@ -346,7 +380,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
     }
 
     PR_SetError(0,0);
-    int status = mOutputFun(buf, readCount, mOutputClosure);
+    status = mOutputFun(buf, readCount, mOutputClosure);
     if (status < 0) {
       PR_SetError(status, 0);
       mOutputFun = NULL;
@@ -358,14 +392,33 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
     mOutputLen += readCount;
   }
 
-  // add final \n to make sure last line is always displayed (bug 5952)
-  buf[0]='\n';
-  PR_SetError(0,0);
-  int status = mOutputFun(buf, 1, mOutputClosure);
-  if (status >= 0) {
-    // ignore any errors here
-    mOutputLen++;
+  
+  if (ctFound==0) {
+    // add mime boundaries around text/plain message (bug 6627)
+    PR_SetError(0,0);
+    strcpy(buf, "\n\n--enigDummy--\n");
+    
+    int status = mOutputFun(buf, strlen(buf), mOutputClosure);
+    if (status < 0) {
+      PR_SetError(status, 0);
+      mOutputFun = NULL;
+      mOutputClosure = NULL;
+
+      return NS_ERROR_FAILURE;
+    }
+    mOutputLen+=strlen(buf);
   }
+  else {
+    // add final \n to make sure last line is always displayed (bug 5952)
+    buf[0]='\n';
+    PR_SetError(0,0);
+    int status = mOutputFun(buf, 1, mOutputClosure);
+    if (status >= 0) {
+      // ignore any errors here
+      mOutputLen++;
+    }
+  }
+  
   PR_SetError(0,0);
 
   // Close input stream
@@ -378,6 +431,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
   PRUint32 statusFlags;
   nsXPIDLString keyId;
   nsXPIDLString userId;
+  nsXPIDLString sigDate;
 
   PRUint32 uiFlags = nsIEnigmail::UI_PGP_MIME;
 
@@ -389,6 +443,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
                                       &statusFlags,
                                       getter_Copies(keyId),
                                       getter_Copies(userId),
+                                      getter_Copies(sigDate),
                                       getter_Copies(errorMsg),
                                       &exitCode);
   if (NS_FAILED(rv)) return rv;
@@ -396,7 +451,7 @@ nsEnigMimeDecrypt::FinishAux(nsIMsgWindow* msgWindow, nsIURI* uri)
   if (securityInfo) {
     nsCOMPtr<nsIEnigMimeHeaderSink> enigHeaderSink = do_QueryInterface(securityInfo);
     if (enigHeaderSink) {
-      rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, exitCode, statusFlags, keyId, userId, errorMsg);
+      rv = enigHeaderSink->UpdateSecurityStatus(uriSpec, exitCode, statusFlags, keyId, userId, sigDate, errorMsg);
     }
   }
 
