@@ -143,6 +143,7 @@ nsEnigMsgCompose::nsEnigMsgCompose()
     mUIFlags(0),
 
     mMultipartSigned(PR_FALSE),
+    mStripWhitespace(PR_FALSE),
 
     mSenderEmailAddr(""),
     mRecipients(""),
@@ -343,15 +344,15 @@ nsEnigMsgCompose::WriteSignedHeaders1(PRBool isEightBit)
     return rv;
 
   char* headers = PR_smprintf(
- "Content-Type: multipart/signed; micalg=pgp-%s;\r\n"
- " protocol=\"application/pgp-signature\";\r\n"
- " boundary=\"%s\"\r\n"
- "%s"
- "This is an OpenPGP/MIME signed message (RFC 2440 and 3156)\r\n"
- "--%s\r\n",
- mHashAlgorithm.get(), mBoundary.get(),
- isEightBit ? "Content-Transfer-Encoding: 8bit\r\n\r\n" : "\r\n",
- mBoundary.get());
+       "Content-Type: multipart/signed; micalg=pgp-%s;\r\n"
+       " protocol=\"application/pgp-signature\";\r\n"
+       " boundary=\"%s\"\r\n"
+       "%s"
+       "This is an OpenPGP/MIME signed message (RFC 2440 and 3156)\r\n"
+       "--%s\r\n",
+       mHashAlgorithm.get(), mBoundary.get(),
+       isEightBit ? "Content-Transfer-Encoding: 8bit\r\n\r\n" : "\r\n",
+       mBoundary.get());
 
   if (!headers)
     return NS_ERROR_OUT_OF_MEMORY;
@@ -460,6 +461,11 @@ nsEnigMsgCompose::Init()
   if (!mPipeTrans)
     return NS_ERROR_FAILURE;
 
+  rv = enigmailSvc->StripWhitespace(mSendFlags,
+                                    &mStripWhitespace);
+  if (NS_FAILED(rv))
+    return rv;
+
   mInitialized = PR_TRUE;
 
   return NS_OK;
@@ -786,7 +792,7 @@ nsEnigMsgCompose::MimeCryptoWriteBlock(const char *aBuf, PRInt32 aLen)
     }
 
     mLinebreak = (aBuf[j] == '\r') || (aBuf[j] == '\n');
-    if ((aBuf[j] == ' ') || (aBuf[j] == '\t')) {
+    if (mStripWhitespace && ((aBuf[j] == ' ') || (aBuf[j] == '\t'))) {
       ++mSpace;
     }
     else {
