@@ -1140,7 +1140,7 @@ function enigEncryptMsg(msgSendType) {
        } else {
          // Encrypt plaintext
          var charset = EnigEditorGetCharset();
-         DEBUG_LOG("enigmailMsgComposeOverlay.js: charset="+charset+"\n");
+         DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: charset="+charset+"\n");
 
          // Encode plaintext to charset from unicode
          var plainText = (sendFlags & ENIG_ENCRYPT)
@@ -1237,6 +1237,33 @@ function enigEncryptMsg(msgSendType) {
        return;
      }
 
+     if (usingPGPMime &&
+         ((sendFlags & ENIG_ENCRYPT_OR_SIGN) &&
+          (! (sendFlags & ENIG_ENCRYPT)))) {
+      // temporarily enable quoted-printable for PGP/MIME signed messages
+       try {
+          if (! gEnigPrefRoot.getBoolPref("mail.strictly_mime")) {
+            gEnigPrefRoot.setBoolPref("mail.strictly_mime", true);
+            newSecurityInfo.UIFlags |= nsIEnigmail.UI_RESTORE_STRICTLY_MIME;
+            DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: enabled quoted-printable\n");
+          }
+
+          // make sure plaintext is not changed to 7bit
+          if (typeof(msgCompFields.forceCharSetEncoding) == "boolean") {
+            msgCompFields.forceCharSetEncoding = true;
+            DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: enabled forceCharSetEncoding\n");
+          }
+       }
+       catch (ex) {}
+    }
+    else if ((! usingPGPMime) && (sendFlags & ENIG_ENCRYPT)) {
+      if (typeof(msgCompFields.forceCharSetEncoding) == "boolean") {
+        // force keeping the charset (i.e. don't convert to us-ascii)
+        msgCompFields.forceCharSetEncoding = true;
+        DEBUG_LOG("enigmailMsgComposeOverlay.js: enigEncryptMsg: enabled forceCharSetEncoding\n");
+      }
+    }
+
   } catch (ex) {
      msg=EnigGetString("signFailed");
      if (gEnigmailSvc && gEnigmailSvc.initializationError) {
@@ -1283,13 +1310,18 @@ function enigMessageSendCheck() {
 /////////////////////////////////////////////////////////////////////////
 function enigModifyCompFields(msgCompFields) {
 
-  var enigmailHeaders = "X-Enigmail-Version: "+gEnigmailVersion+"\r\n"+
-                        "X-Enigmail-Supports: pgp-inline, pgp-mime\r\n";
+  if (EnigGetPref("addHeaders")) {
+    var enigmailHeaders = "X-Enigmail-Version: "+gEnigmailVersion+"\r\n"+
+                          "X-Enigmail-Supports: pgp-inline, pgp-mime\r\n";
 
-  msgCompFields.otherRandomHeaders += enigmailHeaders;
+    msgCompFields.otherRandomHeaders += enigmailHeaders;
 
-  DEBUG_LOG("enigmailMsgComposeOverlay.js: enigModifyCompFields: otherRandomHeaders = "+
-           msgCompFields.otherRandomHeaders+"\n");
+    DEBUG_LOG("enigmailMsgComposeOverlay.js: enigModifyCompFields: otherRandomHeaders = "+
+             msgCompFields.otherRandomHeaders+"\n");
+  }
+  else {
+    DEBUG_LOG("enigmailMsgComposeOverlay.js: enigModifyCompFields: no headers added\n");
+  }
 }
 
 
