@@ -190,7 +190,8 @@ function enigmailDlgOnAccept() {
 
   window.arguments[RESULT].cancelled=false;
   if (window.arguments[INPUT].options.indexOf("nosave")<0) {
-    enigmailSvc.addRule(window.arguments[RESULT].email,
+    enigmailSvc.addRule(false,
+                        window.arguments[RESULT].email,
                         window.arguments[RESULT].keyId,
                         window.arguments[RESULT].sign,
                         window.arguments[RESULT].encrypt,
@@ -223,7 +224,7 @@ function enigmailDlgKeySelection() {
     }
   }
   
-  inputObj.options = "multisel,forUser";
+  inputObj.options = "multisel,forUser,noplaintext";
   var userIdValue="";
 
   window.openDialog("chrome://enigmail/content/enigmailUserSelection.xul","", "dialog,modal,centerscreen", inputObj, resultObj);
@@ -268,7 +269,7 @@ function enigSetKeys(keyList) {
       var keyEnd=userListTxt.substring(keyStart).indexOf("\n");
       var userDescList=userListTxt.substr(keyStart,keyEnd).split(/:/);
      
-      encryptionList.appendItem("0x"+keyList[i].substr(10,8)+" ("+userDescList[6]+")",
+      encryptionList.appendItem("0x"+keyList[i].substr(10,8)+" ("+EnigConvertGpgToUnicode(userDescList[6].replace(/\\e3A/g, ":"))+")",
                                 keyList[i]);
     }
   }
